==> sumo_1.8.0+dfsg2.orig.tar.xz: sumo-1.8.0/docs/web/NOTICE.md <==
## Third-party Content

This Documentation leverages the following third party content.

mkdocs (1.0.4)
* License: BSD 2-Clause "Simplified" License
* Project: https://www.mkdocs.org/
* Source: https://github.com/mkdocs/mkdocs

mkdocs-macros-plugin (0.2.0)
* Author: Laurent Franceschetti
* License: MIT License
* Project: https://pypi.org/project/mkdocs-macros-plugin/
* Source: https://github.com/fralau/mkdocs_macros_plugin

mdx-gh-links (0.2)
* Author: Waylan Limberg
* License: BSD 3-Clause License
* Project: https://pypi.org/project/mdx_gh_links/
* Source: https://github.com/Python-Markdown/github-links

pymdown-extensions (6.0)
* Author: Isaac Muse
* License: MIT License
* Project: https://pypi.org/project/pymdown-extensions/
* Source: https://github.com/facelessuser/pymdown-extensions

mkdocs-git-revision-date-plugin (0.1.5)
* Author: Terry Zhao
* License: MIT License
* Project: https://pypi.org/project/mkdocs-git-revision-date-plugin/
* Source: https://github.com/zhaoterryy/mkdocs-git-revision-date-plugin

mdx_truly_sane_lists (1.2)
* Author: @radude
* License: MIT License
* Project: https://pypi.org/project/mdx-truly-sane-lists/
* Source: https://github.com/radude/mdx_truly_sane_lists

plantuml-markdown (3.2.1)
* Author: Michele Tessaro
* License: BSD 2-Clause License
* Project: https://pypi.org/project/plantuml-markdown/
* Source: https://github.com/mikitex70/plantuml-markdown

PlantUML
* Author: Arnaud Roques
* License: Various alternatives possible including EPL and MIT
* Project: https://plantuml.com/
* Source: https://sourceforge.net/p/plantuml/code/HEAD/tree/trunk/

==> sumo_1.12.0+dfsg1.orig.tar.xz: sumo-1_12_0/docs/web/NOTICE.md <==
## Third-party Content

This Documentation leverages the following third party content:

### mkdocs
* License: BSD 2-Clause "Simplified" License
* Project: https://www.mkdocs.org/
* Source: https://github.com/mkdocs/mkdocs

### mkdocs-macros-plugin
* Author: Laurent Franceschetti
* License: MIT License
* Project: https://pypi.org/project/mkdocs-macros-plugin/
* Source: https://github.com/fralau/mkdocs_macros_plugin

### mdx-gh-links
* Author: Waylan Limberg
* License: BSD 3-Clause License
* Project: https://pypi.org/project/mdx_gh_links/
* Source: https://github.com/Python-Markdown/github-links

### pymdown-extensions
* Author: Isaac Muse
* License: MIT License
* Project: https://pypi.org/project/pymdown-extensions/
* Source: https://github.com/facelessuser/pymdown-extensions

### mkdocs-git-revision-date-plugin
* Author: Terry Zhao
* License: MIT License
* Project: https://pypi.org/project/mkdocs-git-revision-date-plugin/
* Source: https://github.com/zhaoterryy/mkdocs-git-revision-date-plugin

### mdx_truly_sane_lists
* Author: @radude
* License: MIT License
* Project: https://pypi.org/project/mdx-truly-sane-lists/
* Source: https://github.com/radude/mdx_truly_sane_lists

### plantuml-markdown
* Author: Michele Tessaro
* License: BSD 2-Clause License
* Project: https://pypi.org/project/plantuml-markdown/
* Source: https://github.com/mikitex70/plantuml-markdown

### PlantUML
* Author: Arnaud Roques
* License: Various alternatives possible including EPL and MIT
* Project: https://plantuml.com/
* Source: https://sourceforge.net/p/plantuml/code/HEAD/tree/trunk/

### Bootstrap
* License: MIT License
* Project: https://getbootstrap.com/
* Source: https://github.com/twbs/bootstrap

### Font Awesome
* License: CC BY 4.0 license
* Project: https://fontawesome.com/
* Source: https://github.com/FortAwesome/Font-Awesome
